@@ -1,13 +1,11 @@
-from __future__ import unicode_literals
-
 from django.db import models
-from django.utils.encoding import python_2_unicode_compatible
+from django.utils import timezone
 
 
-@python_2_unicode_compatible
 class Article(models.Model):
     title = models.CharField(max_length=100)
     pub_date = models.DateField()
+    pub_datetime = models.DateTimeField(default=timezone.now())
 
     categories = models.ManyToManyField("Category", related_name="articles")
 
@@ -15,7 +13,6 @@ class Article(models.Model):
         return self.title
 
 
-@python_2_unicode_compatible
 class Comment(models.Model):
     article = models.ForeignKey(Article, models.CASCADE, related_name="comments")
     text = models.TextField()
